@@ -1,14 +1,14 @@
 <?php
 /**
- * $Horde: horde/admin/phpshell.php,v 1.24.10.4 2005/07/05 08:40:27 jan Exp $
+ * $Horde: horde/admin/phpshell.php,v 1.24.10.9 2007/01/02 13:54:03 jan Exp $
  *
- * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
-define('HORDE_BASE', dirname(__FILE__) . '/..');
+@define('HORDE_BASE', dirname(__FILE__) . '/..');
 require_once HORDE_BASE . '/lib/base.php';
 require_once 'Horde/Menu.php';
 require_once 'Horde/Help.php';
@@ -29,10 +29,11 @@ foreach ($apps_tmp as $app) {
 asort($apps);
 $application = Util::getFormData('app', 'horde');
 ?>
+<div style="padding:10px">
 <form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="post">
 <?php Util::pformInput() ?>
 
-<table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header"><?php echo _("Application") ?></td></tr></table>
+<h1 class="header"><?php echo _("Application") ?></h1><br />
 <select name="app">
 <?php foreach ($apps as $app => $name): ?>
   <option value="<?php echo $app ?>"<?php if ($application == $app) echo ' selected="selected"' ?>><?php echo $name ?></option>
@@ -65,13 +66,13 @@ if ($command = trim(Util::getFormData('php'))) {
                           $pretty);
     $pretty = MIME_Viewer_Source::lineNumber(trim($pretty));
 
-    echo '<table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header">' . _("PHP Code") . '</td></tr></table><br />';
+    echo '<h1 class="header">' . _("PHP Code") . '</h1><br />';
     echo $pretty;
 
-    echo '<br /><table width="100%" border="0" cellpadding="2" cellspacing="0"><tr><td class="header">' . _("Results") . '</td></tr></table>';
-    echo '<table cellpadding="4" border="0"><tr><td class="text"><pre>';
+    echo '<br /><h1 class="header">' . _("Results") . '</h1><br />';
+    echo '<pre class="text">';
     eval($command);
-    echo '</pre></td></tr></table><br />';
+    echo '</pre><br />';
 }
 ?>
 
@@ -82,6 +83,7 @@ if ($command = trim(Util::getFormData('php'))) {
 <?php echo Help::link('admin', 'admin-phpshell') ?>
 
 </form>
+</div>
 <?php
 
 require HORDE_TEMPLATES . '/common-footer.inc';
