@@ -3,9 +3,9 @@
  * Contains functions related to managing
  * Access Control Lists.
  *
- * $Horde: framework/IMAP/IMAP/ACL.php,v 1.2.12.5 2005/07/03 04:39:57 selsky Exp $
+ * $Horde: framework/IMAP/IMAP/ACL.php,v 1.2.12.11 2007/01/02 13:54:22 jan Exp $
  *
- * Copyright 2003-2005 Chris Hastie <imp@oak-wood.co.uk>
+ * Copyright 2003-2007 Chris Hastie <imp@oak-wood.co.uk>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -40,9 +40,9 @@ class IMAP_ACL {
     /**
      * Hash containing the list of possible rights and a human
      * readable description of each
-     * 
+     *
      * Array (
-     *     right-id => right-description   
+     *     right-id => right-description
      * )
      *
      * @var array
@@ -50,7 +50,7 @@ class IMAP_ACL {
     var $_rightsList = array();
 
     /**
-     * Array containing user names that can not have their access
+     * Array containing user names that cannot have their access
      * rights changed.
      *
      * @var boolean
@@ -65,12 +65,11 @@ class IMAP_ACL {
     function IMAP_ACL($params = array())
     {
         $this->_params = $params;
-    }    
+    }
 
     /**
-     * Attempts to retrieve the existing ACL for a folder from 
-     * the current IMAP server. If protocol is imap/ssl, will
-     * only attempt ssl connection with PHP >= 4.3
+     * Attempts to retrieve the existing ACL for a folder from
+     * the current IMAP server.
      *
      * @param string folder  The folder to get the ACL for
      *
@@ -90,10 +89,10 @@ class IMAP_ACL {
      * Sets the ACL on an IMAP server
      *
      * @param string $folder  The folder on which to edit the ACL
-     *                           
+     *
      * @param string $share_user  The user to grant rights to
      *
-     * @param array $acl  An array, the keys of which are the 
+     * @param array $acl  An array, the keys of which are the
      *                    rights to be granted (see RFC 2086)
      *
      * @return mixed  True on success, false on failure unless
@@ -108,10 +107,10 @@ class IMAP_ACL {
      * Edits an ACL on an IMAP server
      *
      * @param string $folder  The folder on which to edit the ACL
-     *                           
+     *
      * @param string $share_user  The user to grant rights to
      *
-     * @param array $acl  An array, the keys of which are the 
+     * @param array $acl  An array, the keys of which are the
      *                    rights to be granted (see RFC 2086)
      *
      * @return mixed  True on success, false on failure unless
@@ -120,10 +119,10 @@ class IMAP_ACL {
     function editACL($folder, $share_user, $acl)
     {
         return false;
-    }    
+    }
 
     /**
-     * Can a user edit the ACL for this folder? Returns true if $user   
+     * Can a user edit the ACL for this folder? Returns true if $user
      * permission to edit the ACL on $folder
      *
      * @param string $folder  The folder name
@@ -175,10 +174,12 @@ class IMAP_ACL {
         require_once dirname(__FILE__) . '/ACL/' . $driver . '.php';
         $class = 'IMAP_ACL_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $acl = &new $class($params);
         } else {
-            return false;
+            $acl = false;
         }
+
+        return $acl;
     }
 
     /**
