@@ -1,66 +1,71 @@
 <?php
 /**
- * This class provides an interface to all identities a user might
- * have. Its methods take care of any site-specific restrictions
- * configured in prefs.php and conf.php.
+ * This class provides an interface to all identities a user might have. Its
+ * methods take care of any site-specific restrictions configured in prefs.php
+ * and conf.php.
  *
- * $Horde: framework/Identity/Identity.php,v 1.50.10.2 2005/03/04 20:44:30 jan Exp $
+ * $Horde: framework/Prefs/Identity.php,v 1.1.2.7 2007/05/07 21:44:38 jan Exp $
  *
- * Copyright 2001-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.50.10.2 $
  * @since   Horde 1.3.5
- * @package Horde_Identity
+ * @package Horde_Prefs
  */
 class Identity {
 
     /**
      * Array containing all the user's identities.
-     * @var array $identities
+     *
+     * @var array
      */
     var $_identities = array();
 
     /**
      * A pointer to the user's standard identity.
-     * This one is used by the methods returning values
-     * if no other one is specified.
-     * @var integer $default
+     * This one is used by the methods returning values if no other one is
+     * specified.
+     *
+     * @var integer
      */
     var $_default = 0;
 
     /**
      * The user whose identities these are.
-     * @var string $user
+     *
+     * @var string
      */
     var $_user = null;
 
     /**
      * Array containing all of the properties in this identity.
-     * @var array $properties
+     *
+     * @var array
      */
     var $_properties = array('id', 'fullname', 'from_addr');
 
     /**
      * Reference to the prefs object that this Identity points to.
-     * @var object Prefs $prefs
+     *
+     * @var Prefs
      */
     var $_prefs;
 
     /**
-     * Reads all the user's identities from the prefs object or builds
-     * a new identity from the standard values given in prefs.php.
+     * Reads all the user's identities from the prefs object or builds a new
+     * identity from the standard values given in prefs.php.
      *
-     * @param optional string $user  If specified, we read another user's
-     *                               identities instead of the current user.
+     * @param string $user  If specified, we read another user's identities
+     *                      instead of the current user.
      */
     function Identity($user = null)
     {
         $this->_user = $user;
-        if (is_null($user) || $user == Auth::getAuth()) {
+        if ((is_null($user) || $user == Auth::getAuth()) &&
+            isset($GLOBALS['prefs'])) {
             $this->_prefs = &$GLOBALS['prefs'];
         } else {
             $this->_prefs = &Prefs::singleton($GLOBALS['conf']['prefs']['driver'],
@@ -68,14 +73,15 @@ class Identity {
                                               $user, '', null, false);
             $this->_prefs->retrieve();
         }
-        $this->_default = $this->_prefs->getValue('default_identity');
 
         if (!($this->_identities = @unserialize($this->_prefs->getValue('identities', false)))) {
             /* Convert identities from the old format. */
-            $this->_identities = unserialize($this->_prefs->getValue('identities'));
+            $this->_identities = @unserialize($this->_prefs->getValue('identities'));
         } elseif (is_array($this->_identities)) {
             $this->_identities = $this->_prefs->convertFromDriver($this->_identities, NLS::getCharset());
         }
+
+        $this->setDefault($this->_prefs->getValue('default_identity'));
     }
 
     /**
@@ -113,11 +119,12 @@ class Identity {
      */
     function save()
     {
-        if (is_array($this->_identities)) {
-            $this->_identities = $this->_prefs->convertToDriver($this->_identities, NLS::getCharset());
+        $identities = $this->_identities;
+        if (is_array($identities)) {
+            $identities = $this->_prefs->convertToDriver($identities, NLS::getCharset());
         }
 
-        $this->_prefs->setValue('identities', serialize($this->_identities), false);
+        $this->_prefs->setValue('identities', serialize($identities), false);
         $this->_prefs->setValue('default_identity', $this->_default);
     }
 
@@ -184,8 +191,7 @@ class Identity {
      * exist or is locked, the property is retrieved from the prefs backend.
      *
      * @param string $key        The property to retrieve.
-     * @param integer $identity  (optional) The identity to retrieve the
-     *                           property from.
+     * @param integer $identity  The identity to retrieve the property from.
      *
      * @return mixed  The value of the property.
      */
@@ -226,7 +232,7 @@ class Identity {
      *
      * @param string $key        The property to set
      * @param mixed $val         The value to which the property should be set
-     * @param integer $identity  (optional) The identity to set the property in
+     * @param integer $identity  The identity to set the property in.
      *
      * @return boolean  True on success, false on failure (property was locked)
      */
@@ -245,8 +251,8 @@ class Identity {
     }
 
     /**
-     * Returns true if all properties are locked and therefore nothing
-     * in the identities can be changed.
+     * Returns true if all properties are locked and therefore nothing in the
+     * identities can be changed.
      *
      * @return boolean  True if all properties are locked, false otherwise
      */
@@ -273,7 +279,8 @@ class Identity {
     {
         $list = $this->getAll($key);
         foreach ($list as $valueB) {
-            if (strpos(String::lower($valueA), String::lower($valueB)) !== false) {
+            if (!empty($valueB) &&
+                strpos(String::lower($valueA), String::lower($valueB)) !== false) {
                 return true;
             }
         }
@@ -283,7 +290,7 @@ class Identity {
     /**
      * Verifies and sanitizes all identity properties.
      *
-     * @param integer $identity  (optional) The identity to verify.
+     * @param integer $identity  The identity to verify.
      *
      * @return bool|object  True if the properties are valid or a PEAR_Error
      *                      with an error description otherwise.
@@ -298,21 +305,19 @@ class Identity {
             $this->setValue('id', _("Unnamed"), $identity);
         }
 
-        /* RFC 2822 [3.2.5] does not allow the '\' character to be used in
-           the personal portion of an e-mail string. */
+        /* RFC 2822 [3.2.5] does not allow the '\' character to be used in the
+         * personal portion of an e-mail string. */
         if (strpos($this->getValue('fullname', $identity), '\\') !== false) {
-            return PEAR::raiseError(_("You can not have the '\\' character in your full name."));
+            return PEAR::raiseError(_("You cannot have the '\\' character in your full name."));
         }
 
         return true;
     }
 
     /**
-     * Generate the from address to use for the default identity.
+     * Generates the from address to use for the default identity.
      *
-     * @access public
-     *
-     * @param optional boolean $fullname  Include the fullname information.
+     * @param boolean $fullname  Include the fullname information.
      *
      * @return string  The default from address.
      */
@@ -329,7 +334,7 @@ class Identity {
 
         $addr = $this->getValue('from_addr');
         if (empty($addr)) {
-            $addr = Auth::getAuth();
+            $addr = $this->_user;
         }
 
         return $from_addr . '<' . $addr . '>';
@@ -343,11 +348,11 @@ class Identity {
      *                      code is dynamically included. If $type is an array,
      *                      then we will look in $type[0]/lib/Identity/ for
      *                      the subclass implementation named $type[1].php.
-     * @param string $user  (optional) If specified, we read another user's
-     *                      identities instead of the current user.
+     * @param string $user  If specified, we read another user's identities
+     *                      instead of the current user.
      *
-     * @return object Identity  The newly created concrete Identity instance,
-     *                          or false on an error.
+     * @return Identity  The newly created concrete Identity instance, or false
+     *                   on an error.
      */
     function &factory($type = 'none', $user = null)
     {
@@ -383,9 +388,9 @@ class Identity {
     }
 
     /**
-     * Attempts to return a reference to a concrete Identity instance
-     * based on $type. It will only create a new instance if no
-     * Identity instance with the same parameters currently exists.
+     * Attempts to return a reference to a concrete Identity instance based on
+     * $type. It will only create a new instance if no Identity instance with
+     * the same parameters currently exists.
      *
      * This should be used if multiple types of identities (and, thus,
      * multiple Identity instances) are required.
@@ -397,11 +402,10 @@ class Identity {
      *                      code is dynamically included. If $type is an array,
      *                      then we will look in $type[0]/lib/Identity/ for
      *                      the subclass implementation named $type[1].php.
-     * @param string $user  (optional) If specified, we read another user's
-     *                      identities instead of the current user.
+     * @param string $user  If specified, we read another user's identities
+     *                      instead of the current user.
      *
-     * @return object Identity  The concrete Identity reference, or false on an
-     *                          error.
+     * @return Identity  The concrete Identity reference, or false on an error.
      */
     function &singleton($type = 'none', $user = null)
     {
