@@ -47,7 +47,7 @@ define('MIME_STRING', 2);
 /**
  * The MIME:: class provides methods for dealing with MIME standards.
  *
- * $Horde: framework/MIME/MIME.php,v 1.139.4.23 2007/01/11 23:45:39 jan Exp $
+ * $Horde: framework/MIME/MIME.php,v 1.139.4.26 2007/06/15 13:57:32 slusarz Exp $
  *
  * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -165,17 +165,28 @@ class MIME {
      */
     function _encode($text, $charset)
     {
-        $char_len = strlen($charset);
-        $txt_len = strlen($text) * 2;
+        $encoded = trim(base64_encode($text));
+        $c_size = strlen($charset) + 7;
 
-        /* RFC 2047 [2] states that no encoded word can be more than 75
-           characters long. If longer, you must split the word. */
-        if (($txt_len + $char_len + 7) > 75) {
-            $pos = intval((68 - $char_len) / 2);
-            return MIME::_encode(substr($text, 0, $pos), $charset) . ' ' . MIME::_encode(substr($text, $pos), $charset);
+        if ((strlen($encoded) + $c_size) > 75) {
+            $parts = explode("\r\n", rtrim(chunk_split($encoded, intval((75 - $c_size) / 4) * 4)));
         } else {
-            return '=?' . $charset . '?b?' . trim(base64_encode($text)) . '?=';
+            $parts[] = $encoded;
         }
+
+        $p_size = count($parts);
+        $out = '';
+        foreach ($parts as $key => $val) {
+            $out .= '=?' . $charset . '?b?' . $val . '?=';
+            if ($p_size > $key + 1) {
+                /* RFC 2047 [2] states that no encoded word can be more than
+                 * 75 characters long. If longer, you must split the word with
+                 * CRLF SPACE. */
+                $out .= "\r\n ";
+            }
+        }
+
+        return $out;
     }
 
     /**
@@ -301,7 +312,7 @@ class MIME {
         }
 
         /* Take out any spaces between multiple encoded words. */
-        $string = preg_replace('|\?=\s=\?|', '?==?', $string);
+        $string = preg_replace('|\?=\s+=\?|', '?==?', $string);
 
         /* Save any preceding text. */
         $preceding = substr($string, 0, $pos);
