@@ -3,10 +3,10 @@
  * The MIME_Viewer_plain class renders out plain text with URLs made
  * into hyperlinks (if viewing inline).
  *
- * $Horde: framework/MIME/MIME/Viewer/plain.php,v 1.18.6.7 2005/07/03 05:04:10 selsky Exp $
+ * $Horde: framework/MIME/MIME/Viewer/plain.php,v 1.18.6.11 2007/01/02 13:54:25 jan Exp $
  *
- * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 2002-2005 Michael Slusarz <slusarz@horde.org>
+ * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 2002-2007 Michael Slusarz <slusarz@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -50,7 +50,7 @@ class MIME_Viewer_plain extends MIME_Viewer {
     /**
      * Return the MIME content type of the rendered content.
      *
-     * @return string  The content type of the output. 
+     * @return string  The content type of the output.
      */
     function getType()
     {
@@ -61,20 +61,26 @@ class MIME_Viewer_plain extends MIME_Viewer {
     /**
      * Format flowed text for HTML output.
      *
-     * @param string $text  The text to format.
-     * @param integer $opt  The optimal length to wrap.
-     * @param integer $max  The maximum length to wrap. 0 means don't wrap.
+     * @param string $text    The text to format.
+     * @param integer $opt    The optimal length to wrap.
+     * @param integer $max    The maximum length to wrap. 0 means don't wrap.
+     * @param boolean $delsp  Was text created with DelSp formatting?
      *
      * @return string  The formatted text.
      */
-    function _formatFlowed($text, $opt = 90, $max = null)
+    function _formatFlowed($text, $opt = null, $max = null, $delsp = null)
     {
         require_once 'Text/Flowed.php';
-        $flowed = &new Text_Flowed($this->mime_part->replaceEOL($text, "\n"));
-        $flowed->setOptLength($opt);
+        $flowed = &new Text_Flowed($this->mime_part->replaceEOL($text, "\n"), $this->mime_part->getCharset());
+        if (!is_null($opt)) {
+            $flowed->setOptLength($opt);
+        }
         if (!is_null($max)) {
             $flowed->setMaxLength($max);
         }
+        if (!is_null($delsp)) {
+            $flowed->setDelSp($delsp);
+        }
         return $flowed->toFixed();
     }
 
