@@ -1,16 +1,14 @@
 <?php
 
-require_once 'Horde/Util.php';
-
 $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
 
 /**
  * The String:: class provides static methods for charset and locale safe
  * string manipulation.
  *
- * $Horde: framework/Util/String.php,v 1.43.6.8 2005/07/03 05:22:37 selsky Exp $
+ * $Horde: framework/Util/String.php,v 1.43.6.14 2007/01/02 13:54:47 jan Exp $
  *
- * Copyright 2003-2005 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2007 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -21,6 +19,26 @@ $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
  */
 class String {
 
+    /**
+     * Caches the result of extension_loaded() calls.
+     *
+     * @param string $ext  The extension name.
+     *
+     * @return boolean  Is the extension loaded?
+     *
+     * @see Util::extensionExists()
+     */
+    function extensionExists($ext)
+    {
+        static $cache = array();
+
+        if (!isset($cache[$ext])) {
+            $cache[$ext] = extension_loaded($ext);
+        }
+
+        return $cache[$ext];
+    }
+
     /**
      * Sets a default charset that the String:: methods will use if none is
      * explicitely specified.
@@ -30,7 +48,7 @@ class String {
     function setDefaultCharset($charset)
     {
         $GLOBALS['_HORDE_STRING_CHARSET'] = $charset;
-        if (Util::extensionExists('mbstring') &&
+        if (String::extensionExists('mbstring') &&
             function_exists('mb_regex_encoding')) {
             @mb_regex_encoding($charset);
         }
@@ -44,18 +62,16 @@ class String {
      * The original string is returned if conversion failed or none
      * of the extensions were available.
      *
-     * @param mixed $input        The data to be converted. If $input is an an
-     *                            array, the array's values get converted
-     *                            recursively.
-     * @param string $from        The string's current charset.
-     * @param string $to          The charset to convert the string to. If not
-     *                            specified, the global variable
-     *                            $_HORDE_STRING_CHARSET will be used.
-     * @param boolean $recursion  Internally used.
+     * @param mixed $input  The data to be converted. If $input is an an array,
+     *                      the array's values get converted recursively.
+     * @param string $from  The string's current charset.
+     * @param string $to    The charset to convert the string to. If not
+     *                      specified, the global variable
+     *                      $_HORDE_STRING_CHARSET will be used.
      *
      * @return string  The converted string.
      */
-    function convertCharset($input, $from, $to = null, $recursion = false)
+    function convertCharset($input, $from, $to = null)
     {
         /* Get the user's default character set if none passed in. */
         if (is_null($to)) {
@@ -63,10 +79,8 @@ class String {
         }
 
         /* If the from and to character sets are identical, return now. */
-        if (!$recursion) {
-            $from = String::lower($from);
-            $to = String::lower($to);
-        }
+        $from = String::lower($from);
+        $to = String::lower($to);
         if ($from == $to) {
             return $input;
         }
@@ -74,14 +88,14 @@ class String {
         if (is_array($input)) {
             $tmp = array();
             foreach ($input as $key => $val) {
-                $tmp[String::convertCharset($key, $from, $to, true)] = String::convertCharset($val, $from, $to, true);
+                $tmp[String::_convertCharset($key, $from, $to)] = String::convertCharset($val, $from, $to);
             }
             return $tmp;
         }
         if (is_object($input)) {
             $vars = get_object_vars($input);
             foreach ($vars as $key => $val) {
-                $input->$key = String::convertCharset($val, $from, $to, true);
+                $input->$key = String::convertCharset($val, $from, $to);
             }
             return $input;
         }
@@ -90,7 +104,23 @@ class String {
             return $input;
         }
 
-        $output = false;
+        return String::_convertCharset($input, $from, $to);
+    }
+
+    /**
+     * Internal function used to do charset conversion.
+     *
+     * @access private
+     *
+     * @param mixed $input  See String::convertCharset().
+     * @param string $from  See String::convertCharset().
+     * @param string $to    See String::convertCharset().
+     *
+     * @return string  The converted string.
+     */
+    function _convertCharset($input, $from, $to)
+    {
+        $output = '';
 
         /* Use utf8_[en|de]code() if possible. */
         $from_check = (($from == 'iso-8859-1') || ($from == 'us-ascii'));
@@ -104,29 +134,25 @@ class String {
         }
 
         /* First try iconv with transliteration. */
-        if ($from != 'utf7-imap' &&
-            $to != 'utf7-imap' &&
-            Util::extensionExists('iconv')) {
-            ini_set('track_errors', 1);
+        if (($from != 'utf7-imap') &&
+            ($to != 'utf7-imap') &&
+            String::extensionExists('iconv')) {
             /* We need to tack an extra character temporarily because
              * of a bug in iconv() if the last character is not a 7
              * bit ASCII character. */
+            ini_set('track_errors', 1);
             $output = @iconv($from, $to . '//TRANSLIT', $input . 'x');
-            if (isset($php_errormsg)) {
-                $output = false;
-            } else {
-                $output = String::substr($output, 0, -1, $to);
-            }
+            $output = (isset($php_errormsg)) ? false :  String::substr($output, 0, -1, $to);
             ini_restore('track_errors');
         }
 
         /* Next try mbstring. */
-        if (!$output && Util::extensionExists('mbstring')) {
+        if (!$output && String::extensionExists('mbstring')) {
             $output = @mb_convert_encoding($input, $to, $from);
         }
 
         /* At last try imap_utf7_[en|de]code if appropriate. */
-        if (!$output && Util::extensionExists('imap')) {
+        if (!$output && String::extensionExists('imap')) {
             if ($from_check && ($to == 'utf7-imap')) {
                 return @imap_utf7_encode($input);
             }
@@ -135,7 +161,7 @@ class String {
             }
         }
 
-        return !$output ? $input : $output;
+        return (!$output) ? $input : $output;
     }
 
     /**
@@ -155,7 +181,7 @@ class String {
 
         if ($locale) {
             /* The existence of mb_strtolower() depends on the platform. */
-            if (Util::extensionExists('mbstring') &&
+            if (String::extensionExists('mbstring') &&
                 function_exists('mb_strtolower')) {
                 if (is_null($charset)) {
                     $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
@@ -262,7 +288,7 @@ class String {
      */
     function substr($string, $start, $length = null, $charset = null)
     {
-        if (Util::extensionExists('mbstring')) {
+        if (String::extensionExists('mbstring')) {
             if (is_null($charset)) {
                 $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
             }
@@ -291,10 +317,14 @@ class String {
      */
     function length($string, $charset = null)
     {
-        if (Util::extensionExists('mbstring')) {
-            if (is_null($charset)) {
-                $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
-            }
+        if (is_null($charset)) {
+            $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
+        }
+        $charset = String::lower($charset);
+        if ($charset == 'utf-8' || $charset == 'utf8') {
+            return strlen(utf8_decode($string));
+        }
+        if (String::extensionExists('mbstring')) {
             $ret = @mb_strlen($string, $charset);
             if (!empty($ret)) {
                 return $ret;
@@ -318,7 +348,7 @@ class String {
      */
     function pos($haystack, $needle, $offset = 0, $charset = null)
     {
-        if (Util::extensionExists('mbstring')) {
+        if (String::extensionExists('mbstring')) {
             if (is_null($charset)) {
                 $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
             }
@@ -438,7 +468,7 @@ class String {
      */
     function isAlpha($string, $charset = null)
     {
-        if (Util::extensionExists('mbstring')) {
+        if (String::extensionExists('mbstring')) {
             $old_charset = mb_regex_encoding();
             if ($charset != $old_charset) {
                 @mb_regex_encoding($charset);
@@ -483,4 +513,37 @@ class String {
                 String::isAlpha($string, $charset));
     }
 
+    /**
+     * Performs a multibyte safe regex match search on the text provided.
+     *
+     * @since Horde 3.1
+     *
+     * @param string $text     The text to search.
+     * @param array $regex     The regular expressions to use, without perl
+     *                         regex delimiters (e.g. '/' or '|').
+     * @param string $charset  The character set of the text.
+     *
+     * @return array  The matches array from the first regex that matches.
+     */
+    function regexMatch($text, $regex, $charset = null)
+    {
+        if (!empty($charset)) {
+            $regex = String::convertCharset($regex, $charset, 'utf-8');
+            $text = String::convertCharset($text, $charset, 'utf-8');
+        }
+
+        $matches = array();
+        foreach ($regex as $val) {
+            if (preg_match('/' . $val . '/u', $text, $matches)) {
+                break;
+            }
+        }
+
+        if (!empty($charset)) {
+            $matches = String::convertCharset($matches, 'utf-8', $charset);
+        }
+
+        return $matches;
+    }
+
 }
