@@ -5,14 +5,14 @@ require_once dirname(__FILE__) . '/Widget.php';
 /**
  * The Horde_UI_Tabs:: class manages and renders a tab-like interface.
  *
- * $Horde: framework/UI/UI/Tabs.php,v 1.27.6.1 2005/01/03 12:19:19 jan Exp $
+ * $Horde: framework/UI/UI/Tabs.php,v 1.27.6.11 2007/01/02 13:54:46 jan Exp $
  *
- * Copyright 2001-2003 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
+ * Copyright 2001-2007 Robert E. Coyle <robertecoyle@hotmail.com>
+ * Copyright 2003-2007 Jason M. Felice <jfelice@cronosys.com>
  *
- * See the enclosed file LICENSE for license information (LGPL).
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @version $Revision: 1.27.6.1 $
  * @since   Horde_UI 0.0.1
  * @package Horde_UI
  */
@@ -20,28 +20,33 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
 
     /**
      * The array of tabs.
-     * @var array $_tabs
+     *
+     * @var array
      */
     var $_tabs = array();
 
     /**
      * Add a tab to the interface.
      *
-     * @access public
-     *
      * @param string $title    The text which appears on the tab.
      * @param string $link     The target page.
-     * @param string $tabname  The value to set the tab variable to.
+     * @param mixed  $params   Either a string value to set the tab variable to,
+     *                         or a hash of parameters. If an array, the tab variable
+     *                         can be set by the 'tabname' key.
      */
-    function addTab($title, $link, $tabname = null)
+    function addTab($title, $link, $params = array())
     {
-        $this->_tabs[] = array('title' => $title, 'link' => $link, 'tabname' => $tabname);
+        if (!is_array($params)) {
+            $params = array('tabname' => $params);
+        }
+        $this->_tabs[] = array_merge(array('title' => $title,
+                                           'link' => $link,
+                                           'tabname' => null),
+                                     $params);
     }
 
     /**
-     * Retreive the title of the tab with the specified name.
-     *
-     * @access public
+     * Retrieve the title of the tab with the specified name.
      *
      * @param string $tabname  The name of the tab.
      *
@@ -67,7 +72,7 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
      */
     function render($active_tab = null)
     {
-        $html = "<ul class='tabset'>\n";
+        $html = "<div class=\"tabset\"><ul>\n";
 
         $first = true;
         $active = $_SERVER['PHP_SELF'] . $this->_vars->get($this->_name);
@@ -79,21 +84,29 @@ class Horde_UI_Tabs extends Horde_UI_Widget {
                                            $tab['tabname']);
             }
 
-            $class = null;
+            $class = '';
             if ((!is_null($active_tab) && $active_tab == $tab['tabname']) ||
                 ($active == $tab['link'] . $tab['tabname'])) {
-                $class = 'activeTab';
+                $class = ' class="activeTab"';
+            }
+
+            if (!isset($tab['target'])) {
+                $tab['target'] = '';
+            }
+
+            if (!isset($tab['onclick'])) {
+                $tab['onclick'] = '';
             }
 
             $accesskey = Horde::getAccessKey($tab['title']);
 
-            $html .= '<li>' .
-                Horde::link($link, $tab['title'], $class, null, null, null, $accesskey) .
-                str_replace(' ', '&nbsp;', Horde::highlightAccessKey($tab['title'], $accesskey)) .
+            $html .= '<li' . $class . '>' .
+                Horde::link($link, '', '', $tab['target'], $tab['onclick'], null, $accesskey) .
+                Horde::highlightAccessKey(str_replace(' ', '&nbsp;', $tab['title']), $accesskey) .
                 "</a> </li>\n";
         }
 
-        return $html . "</ul>\n";
+        return $html . "</ul></div><br class=\"clear\" />\n";
     }
 
 }
