@@ -2,7 +2,7 @@
 /**
  * Class representing vEvents.
  *
- * $Horde: framework/iCalendar/iCalendar/vevent.php,v 1.31.10.11 2007/01/11 18:17:46 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar/vevent.php,v 1.31.10.12 2007/05/04 15:58:31 jan Exp $
  *
  * Copyright 2003-2007 Mike Cochrane <mike@graftonhall.co.nz>
  *
@@ -114,7 +114,7 @@ class Horde_iCalendar_vevent extends Horde_iCalendar {
     {
         $organizer = $this->getAttribute('ORGANIZER', true);
         if (is_a($organizer, 'PEAR_Error')) {
-            return null;
+            return _("An unknown person");
         }
 
         if (isset($organizer[0]['CN'])) {
