@@ -3,12 +3,12 @@
  * Net_SMS_clickatell_http Class implements the HTTP API for accessing the
  * Clickatell (www.clickatell.com) SMS gateway.
  *
- * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you did
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Net_SMS/SMS/clickatell_http.php,v 1.13.10.9 2006/08/07 00:42:30 chuck Exp $
+ * $Horde: framework/Net_SMS/SMS/clickatell_http.php,v 1.13.10.11 2007/01/02 13:54:29 jan Exp $
  *
  * @author Marko Djukic <marko@oblo.com>
  * @package Net_SMS
@@ -84,12 +84,12 @@ class Net_SMS_clickatell_http extends Net_SMS {
      *
      * @param array $message  The array containing the message and its send
      *                        parameters.
-     * @param string $to      The destination string.
+     * @param array $to       The recipients.
      *
      * @return array  An array with the success status and additional
      *                information.
      */
-    function _send(&$message, $to)
+    function _send($message, $to)
     {
         /* Set up the http sending url. */
         $url = sprintf('sendmsg?session_id=%s&text=%s',
